@@ -36,7 +36,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrivateDNSAccount", params)
+            headers = request.headers
+            body = self.call("CreatePrivateDNSAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrivateDNSAccountResponse()
@@ -64,7 +65,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrivateZone", params)
+            headers = request.headers
+            body = self.call("CreatePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrivateZoneResponse()
@@ -92,7 +94,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("CreatePrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePrivateZoneRecordResponse()
@@ -120,7 +123,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrivateDNSAccount", params)
+            headers = request.headers
+            body = self.call("DeletePrivateDNSAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrivateDNSAccountResponse()
@@ -148,7 +152,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrivateZone", params)
+            headers = request.headers
+            body = self.call("DeletePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrivateZoneResponse()
@@ -176,7 +181,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("DeletePrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePrivateZoneRecordResponse()
@@ -204,7 +210,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccountVpcList", params)
+            headers = request.headers
+            body = self.call("DescribeAccountVpcList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccountVpcListResponse()
@@ -232,7 +239,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAuditLog", params)
+            headers = request.headers
+            body = self.call("DescribeAuditLog", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAuditLogResponse()
@@ -260,7 +268,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDashboard", params)
+            headers = request.headers
+            body = self.call("DescribeDashboard", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDashboardResponse()
@@ -288,7 +297,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateDNSAccountList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateDNSAccountList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateDNSAccountListResponse()
@@ -316,7 +326,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZone", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneResponse()
@@ -344,7 +355,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneListResponse()
@@ -372,7 +384,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneRecordList", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneRecordList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneRecordListResponse()
@@ -400,7 +413,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrivateZoneService", params)
+            headers = request.headers
+            body = self.call("DescribePrivateZoneService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePrivateZoneServiceResponse()
@@ -428,7 +442,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeQuotaUsage", params)
+            headers = request.headers
+            body = self.call("DescribeQuotaUsage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeQuotaUsageResponse()
@@ -456,7 +471,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRequestData", params)
+            headers = request.headers
+            body = self.call("DescribeRequestData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRequestDataResponse()
@@ -484,7 +500,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZone", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZone", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneResponse()
@@ -512,7 +529,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZoneRecord", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZoneRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneRecordResponse()
@@ -540,7 +558,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPrivateZoneVpc", params)
+            headers = request.headers
+            body = self.call("ModifyPrivateZoneVpc", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPrivateZoneVpcResponse()
@@ -558,6 +577,35 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyRecordsStatus(self, request):
+        """修改解析记录状态
+
+        :param request: Request instance for ModifyRecordsStatus.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyRecordsStatusRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.ModifyRecordsStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyRecordsStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyRecordsStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SubscribePrivateZoneService(self, request):
         """开通私有域解析
 
@@ -568,7 +616,8 @@ class PrivatednsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SubscribePrivateZoneService", params)
+            headers = request.headers
+            body = self.call("SubscribePrivateZoneService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SubscribePrivateZoneServiceResponse()
